==> activity-center-api-0.9.69-mhs3-20190910.111102-3-sources.jar: cn/com/duiba/tuia/activity/center/api/dto/req/ReqActivityQuery.java <==
package cn.com.duiba.tuia.activity.center.api.dto.req;

import java.util.Date;
import java.util.List;

/**
 * Created by xuefeng on 2017/12/29.
 */
public class ReqActivityQuery extends ReqPageQuery {
    private static final long serialVersionUID = 1L;

    private Long id;
    String title;
    Integer type;
    Integer overseas;
    /*
    1-普通活动 2-自定义活动 3-直投活动 4-原生化活动
     */
    private List<Integer> activityDefType;
    private List<Long> activityIds;
    private Long tagId;
    private Date activityCreateStart;
    private Date activityCreateEnd;
    private Integer top;
    private Boolean isOpen;
    private String skinName;
    private String subType;
    private Integer isEnc;

    /**
     * 策划人
     */
    private String activityPlaner;
    /**
     * 排序
     */
    private String order;
    /**
     * 活动分类：0：全部，1：自定义活动工具，2：原生活动，3：直投页
     */
    private Integer activityCategory;
    /**
     * 我的收藏
     */
    private Boolean favorite;
    /**
     * 收藏人ID
     */
    private Long userId;

    /** 活动标签过滤的活动列表 */
    private List<Long> activityIdsByTags;

    /** 活动状态：0：未添加活动推广计划，1：计划开启，2：计划关闭，3：测试中 */
    private Integer activityPlanStatus;

    public String getSubType() {
        return subType;
    }

    public void setSubType(String subType) {
        this.subType = subType;
    }

    public String getSkinName() {
        return skinName;
    }

    public void setSkinName(String skinName) {
        this.skinName = skinName;
    }

    public Boolean getIsOpen() {
        return isOpen;
    }

    public void setIsOpen(Boolean isOpen) {
        this.isOpen = isOpen;
    }

    public ReqActivityQuery() {
        super();
    }

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public String getTitle() {
        return title;
    }

    public void setTitle(String title) {
        this.title = title;
    }

    public Integer getType() {
        return type;
    }

    public void setType(Integer type) {
        this.type = type;
    }

    public Integer getOverseas() {
        return overseas;
    }

    public void setOverseas(Integer overseas) {
        this.overseas = overseas;
    }

    public Date getActivityCreateStart() {
        return activityCreateStart;
    }

    public void setActivityCreateStart(Date activityCreateStart) {
        this.activityCreateStart = activityCreateStart;
    }

    public Date getActivityCreateEnd() {
        return activityCreateEnd;
    }

    public void setActivityCreateEnd(Date activityCreateEnd) {
        this.activityCreateEnd = activityCreateEnd;
    }

    public Long getTagId() {
        return tagId;
    }

    public void setTagId(Long tagId) {
        this.tagId = tagId;
    }

    public List<Long> getActivityIds() {
        return activityIds;
    }

    public void setActivityIds(List<Long> activityIds) {
        this.activityIds = activityIds;
    }

    public Integer getTop() {
        return top;
    }

    public void setTop(Integer top) {
        this.top = top;
    }

    public List<Integer> getActivityDefType() {
        return activityDefType;
    }

    public void setActivityDefType(List<Integer> activityDefType) {
        this.activityDefType = activityDefType;
    }

    public Integer getIsEnc() {
        return isEnc;
    }

    public void setIsEnc(Integer isEnc) {
        this.isEnc = isEnc;
    }

    public String getActivityPlaner() {
        return activityPlaner;
    }

    public void setActivityPlaner(String activityPlaner) {
        this.activityPlaner = activityPlaner;
    }

    public String getOrder() {
        return order;
    }

    public void setOrder(String order) {
        this.order = order;
    }

    public Integer getActivityCategory() {
        return activityCategory;
    }

    public void setActivityCategory(Integer activityCategory) {
        this.activityCategory = activityCategory;
    }

    public Boolean getFavorite() {
        return favorite;
    }

    public void setFavorite(Boolean favorite) {
        this.favorite = favorite;
    }

    public Long getUserId() {
        return userId;
    }

    public void setUserId(Long userId) {
        this.userId = userId;
    }

    public List<Long> getActivityIdsByTags() {
        return activityIdsByTags;
    }

    public void setActivityIdsByTags(List<Long> activityIdsByTags) {
        this.activityIdsByTags = activityIdsByTags;
    }

    public Integer getActivityPlanStatus() {
        return activityPlanStatus;
    }

    public void setActivityPlanStatus(Integer activityPlanStatus) {
        this.activityPlanStatus = activityPlanStatus;
    }
}

==> activity-center-api-0.9.73-mhs-20190916.165425-4-sources.jar: cn/com/duiba/tuia/activity/center/api/dto/req/ReqActivityQuery.java <==
package cn.com.duiba.tuia.activity.center.api.dto.req;

import java.util.Date;
import java.util.List;

/**
 * Created by xuefeng on 2017/12/29.
 */
public class ReqActivityQuery extends ReqPageQuery {
    private static final long serialVersionUID = 1L;

    private Long id;
    String title;
    Integer type;
    Integer overseas;
    /*
    1-普通活动 2-自定义活动 3-直投活动 4-原生化活动
     */
    private List<Integer> activityDefType;
    private List<Long> activityIds;
    private Long tagId;
    private Date activityCreateStart;
    private Date activityCreateEnd;
    private Integer top;
    private Boolean isOpen;
    private String skinName;
    private String subType;
    private Integer isEnc;

    /**
     * 策划人
     */
    private String activityPlaner;
    /**
     * 排序
     */
    private String order;
    /**
     * 活动分类：0：全部，1：自定义活动工具，2：原生活动，3：直投页
     */
    private Integer activityCategory;
    /**
     * 我的收藏
     */
    private Boolean favorite;
    /**
     * 收藏人ID
     */
    private Long userId;

    /** 指定活动推广计划状态的活动列表 */
    private List<Long> activityIdsByPlan;
    /** 除了当前用户也被其他人收藏的活动列表 */
    private List<Long> duplicatedActivityIdByUseId;

    /** 活动状态：0：未添加活动推广计划，1：计划开启，2：计划关闭，3：测试中 */
    private Integer activityPlanStatus;

    public String getSubType() {
        return subType;
    }

    public void setSubType(String subType) {
        this.subType = subType;
    }

    public String getSkinName() {
        return skinName;
    }

    public void setSkinName(String skinName) {
        this.skinName = skinName;
    }

    public Boolean getIsOpen() {
        return isOpen;
    }

    public void setIsOpen(Boolean isOpen) {
        this.isOpen = isOpen;
    }

    public ReqActivityQuery() {
        super();
    }

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public String getTitle() {
        return title;
    }

    public void setTitle(String title) {
        this.title = title;
    }

    public Integer getType() {
        return type;
    }

    public void setType(Integer type) {
        this.type = type;
    }

    public Integer getOverseas() {
        return overseas;
    }

    public void setOverseas(Integer overseas) {
        this.overseas = overseas;
    }

    public Date getActivityCreateStart() {
        return activityCreateStart;
    }

    public void setActivityCreateStart(Date activityCreateStart) {
        this.activityCreateStart = activityCreateStart;
    }

    public Date getActivityCreateEnd() {
        return activityCreateEnd;
    }

    public void setActivityCreateEnd(Date activityCreateEnd) {
        this.activityCreateEnd = activityCreateEnd;
    }

    public Long getTagId() {
        return tagId;
    }

    public void setTagId(Long tagId) {
        this.tagId = tagId;
    }

    public List<Long> getActivityIds() {
        return activityIds;
    }

    public void setActivityIds(List<Long> activityIds) {
        this.activityIds = activityIds;
    }

    public Integer getTop() {
        return top;
    }

    public void setTop(Integer top) {
        this.top = top;
    }

    public List<Integer> getActivityDefType() {
        return activityDefType;
    }

    public void setActivityDefType(List<Integer> activityDefType) {
        this.activityDefType = activityDefType;
    }

    public Integer getIsEnc() {
        return isEnc;
    }

    public void setIsEnc(Integer isEnc) {
        this.isEnc = isEnc;
    }

    public String getActivityPlaner() {
        return activityPlaner;
    }

    public void setActivityPlaner(String activityPlaner) {
        this.activityPlaner = activityPlaner;
    }

    public String getOrder() {
        return order;
    }

    public void setOrder(String order) {
        this.order = order;
    }

    public Integer getActivityCategory() {
        return activityCategory;
    }

    public void setActivityCategory(Integer activityCategory) {
        this.activityCategory = activityCategory;
    }

    public Boolean getFavorite() {
        return favorite;
    }

    public void setFavorite(Boolean favorite) {
        this.favorite = favorite;
    }

    public Long getUserId() {
        return userId;
    }

    public void setUserId(Long userId) {
        this.userId = userId;
    }

    public List<Long> getActivityIdsByPlan() {
        return activityIdsByPlan;
    }

    public void setActivityIdsByPlan(List<Long> activityIdsByPlan) {
        this.activityIdsByPlan = activityIdsByPlan;
    }

    public Integer getActivityPlanStatus() {
        return activityPlanStatus;
    }

    public void setActivityPlanStatus(Integer activityPlanStatus) {
        this.activityPlanStatus = activityPlanStatus;
    }

    public List<Long> getDuplicatedActivityIdByUseId() {
        return duplicatedActivityIdByUseId;
    }

    public void setDuplicatedActivityIdByUseId(List<Long> duplicatedActivityIdByUseId) {
        this.duplicatedActivityIdByUseId = duplicatedActivityIdByUseId;
    }
}
